========
apkutils
========


.. image:: https://img.shields.io/pypi/v/apkutils.svg
        :target: https://pypi.python.org/pypi/apkutils

.. image:: https://readthedocs.org/projects/apkutils/badge/?version=latest
        :target: https://apkutils.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/apkutils?color=green
        :alt: PyPI - License

a parser for apk, dex, axml, arsc


* Free software: MIT license
* Documentation: https://apkutils.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `kin9-0rz/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`kin9-0rz/cookiecutter-pypackage`: https://gitee.com/kin9-0rz/cookiecutter-pypackage
